capture log close
log using logfiles/pop_wind_dm.log, replace   
set more off   
                 
clear

*
*	THIS FILE GENERATES THE DATA BASE USED FOR TESTING WIND/UHI EFFECTS
*	WHEN POPULATION FIGURES ARE USED. 
*
*
*
*		INPUTS 						==> 		OUTPUTS
* 
*
*		COMPONENT B
*	INHOM/(CITY FILES)				|| 	==> 	CONTAMINATED URBAN MINTEMP DATA  (monthly)
*
*
*		COMPONENT C
*	HOM/ (CITY FILES)				|| 	==> 	URBAN HOMOG WIND DATA (monthly)
*
*
*		COMPONENT D
*	HOM/ (RURAL FILES)				|| 	==>	CLEAN RURAL MINTEMP DATA (monthly)
*								|| 	==>	RURAL WIND DATA (monthly)
*	
*		COMPONENT E
*	POPULATION.CSV					|| 	==> 	POPULATION (quarterly to monthly) SERIES
*
*		



**********************************************************************************
*	BUILD CITY INHOM TEMP DATA u_min_mon
**********************************************************************************

local start=1979

*	READ CALGARY INHOM DATA
insheet using data/inhom/calgary.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="calgary"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
	save data/calgary.dta, replace
clear


*	READ edmonton CLIMATE DATA
insheet using data/inhom/edmonton.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="edmonton"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/edmonton.dta, replace
clear



*	READ montreal_trudeau CLIMATE DATA
insheet using data/inhom/montreal_trudeau.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="montreal"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/montreal.dta, replace
clear



*	READ ottawa CLIMATE DATA
insheet using data/inhom/ottawa.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="ottawa"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/ottawa.dta, replace
clear



*	READ regina CLIMATE DATA
insheet using data/inhom/regina.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="regina"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
	save data/regina.dta, replace
clear



*	READ saskatoon CLIMATE DATA
insheet using data/inhom/saskatoon.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="saskatoon"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/saskatoon.dta, replace
clear



*	READ toronto CLIMATE DATA
insheet using data/inhom/toronto_pearson.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="toronto"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/toronto.dta, replace
clear



*	READ vancouver CLIMATE DATA
insheet using data/inhom/vancouver.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="vancouver"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/vancouver.dta, replace
clear



*	READ victoria CLIMATE DATA
insheet using data/inhom/victoria.csv, c
sum
describe
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="victoria"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
	save data/victoria.dta, replace
clear


*	READ winnipeg CLIMATE DATA
insheet using data/inhom/winnipeg.csv, c
sum
describe
	drop if _n<20
	destring, replace
sum
	drop if _n<20
	destring, replace
	drop v1 v4-v7 v9-v26			// select desired data and rename vars
	rename v2 year
	rename v3 month
	generate str city="winnipeg"
	drop if year<`start'
	drop if year>2006
	rename v8 u_min_mon
sum
	keep year month u_min_mon city 
		save data/winnipeg.dta, replace
clear


use data/calgary					// form long data sets
	append using data/edmonton
	append using data/montreal
	append using data/ottawa
	append using data/regina
	append using data/saskatoon
	append using data/toronto
	append using data/vancouver
	append using data/victoria
	append using data/winnipeg
	sum

save data/u_min_mon.dta, replace			// MONTHLY MINTEMP DATA FOR BIG CITIES



clear


**********************************************************************************
*	BUILD CITY HOMOG WIND DATA u_wind_mon
**********************************************************************************

*	City Codes
*
*	calgary	3031093
*	edmonton	3012205
*	montreal*	7024745 McTavish
*	ottawa	6106000
*	regina	4016560
*	saskatoon	4057120
*	toronto*	6137287 St Catherines A
*	vancouver*	1100030 Abbotsford A	
*	victoria	1018620
*	winnipeg	5023222


*		WIND data

insheet using data/homog/hom_wind/mws3031093.txt		// Calgary
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=1
sum
	save data/m1.dta, replace
	clear

insheet using data/homog/hom_wind/mws3012205.txt		// Edmonton
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=2
sum
	save data/m2.dta, replace
	clear
	
insheet using data/homog/hom_wind/mws7025250.txt		// Montreal
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=3
sum
	save data/m3.dta, replace
	clear

insheet using data/homog/hom_wind/mws6106000.txt		// Ottawa
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=4
sum
	save data/m4.dta, replace
	clear

insheet using data/homog/hom_wind/mws4016560.txt		// Regina
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=5
sum
	save data/m5.dta, replace
	clear

insheet using data/homog/hom_wind/mws4057120.txt		// Saskatoon
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=6
sum
	save data/m6.dta, replace
	clear

insheet using data/homog/hom_wind/mws6158733.txt		// Toronto
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=7
sum
	save data/m7.dta, replace
	clear

insheet using data/homog/hom_wind/mws1100030.txt		// Vancouver
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=8
	replace v=v[_n-1]+(v[_n+1]-v[_n-1])/2 if v==.		// interpolate missing value
sum
	save data/m8.dta, replace
	clear

insheet using data/homog/hom_wind/mws1018620.txt		// Victoria
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=9
sum
	save data/m9.dta, replace
	clear

insheet using data/homog/hom_wind/mws5023222.txt		// Winnipeg
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=10
sum
	save data/m10.dta, replace
	clear

use data/m1					// Form long data set
	append using data/m2
	append using data/m3
	append using data/m4
	append using data/m5
	append using data/m6
	append using data/m7
	append using data/m8
	append using data/m9
	append using data/m10

rename v u_wind_mon

sum

	save data/u_wind_mon.dta, replace			// MONTHLY HOMOGENIZED WIND DATA FOR BIG CITIES
	clear











**********************************************************************************
*	BUILD REMOTE HOMOG MINTEMP DATA r_min_mon
**********************************************************************************



*		MINTEMP data

insheet using data/homog/hom_mintemp/mn3033880.txt		// Lethbridge AB
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m1.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn3062693.txt		// Fort McMurray AB
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m2.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn7113534.txt		// Kuujjuaq Que
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m3.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn6166418.txt		// Peterborough ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	replace v=v[_n-1]+(v[_n+1]-v[_n-1])/2 if v==.		// interpolate missing value
sum
	save data/m4.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn4028040.txt		// Swift Current SK
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m5.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn4012400.txt		// Estevan SK
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m6.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn6119500.txt		// Wiarton ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m7.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn1077500.txt		// Smithers BC
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m8.dta, replace
	clear

insheet using data/homog/hom_mintemp/mn1036570.txt		// Quatsino BC
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m9.dta, replace
	clear


*
*	REPLACE MISSING OBS IN 2005-06 WITH ESTIMATES USING PORT HARDY 
*


	insheet using data/homog/hom_mintemp/mn1026270.txt		// Port Hardy BC
		drop if _n<3
		keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
		rename v1 year
		destring, replace
		mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
		reshape long v, i(year) j(month)
		replace month=month/2
		drop if year<`start'
		drop if year>2006
		rename v porthardy
		save data/ph.dta, replace

	use data/m10.dta
		merge using data/ph.dta
		generate w=(month==12)+(month==1)+(month==2)		// allow differing seasonal intercepts
		generate s=(month==3)+(month==4)+(month==5)			
		generate f=(month==9)+(month==10)+(month==11)		
		
		regress v w s f porthardy if year<2005
			predict vhat 
			replace v=vhat if v==.
		keep year month v ncity
		save data/m9.dta, replace
		

clear



insheet using data/homog/hom_mintemp/mn6034075.txt		// Kenora ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
sum
	save data/m10.dta, replace
	clear

use data/m1					// Form long data set
	append using data/m2
	append using data/m3
	append using data/m4
	append using data/m5
	append using data/m6
	append using data/m7
	append using data/m8
	append using data/m9
	append using data/m10

rename v r_min_mon

sum

	save data/r_min_mon.dta, replace			// MONTHLY HOMOGENIZED MINTEMP DATA FOR RURAL SITES
	clear





**********************************************************************************
*	BUILD REMOTE HOMOG WIND DATA r_wind_mon
**********************************************************************************



*		WIND data

insheet using data/homog/hom_wind/mws3033880.txt		// Lethbridge AB
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=1
sum
	save data/m1.dta, replace
	clear

insheet using data/homog/hom_wind/mws3062693.txt		// Fort McMurray AB
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=2
sum
	save data/m2.dta, replace
	clear

insheet using data/homog/hom_wind/mws7113534.txt		// Kuujjuaq Que
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=3
sum
	save data/m3.dta, replace
	clear

insheet using data/homog/hom_wind/mws6158875.txt		// *Trenton* near P-brgh ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=4
sum
	save data/m4.dta, replace
	clear

insheet using data/homog/hom_wind/mws4028040.txt		// Swift Current SK
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	replace v=v[_n-1]+(v[_n+1]-v[_n-1])/2 if v==.		// interpolate missing value
	generate ncity=5
sum
	save data/m5.dta, replace
	clear

insheet using data/homog/hom_wind/mws4012400.txt		// Estevan SK
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=6
sum
	save data/m6.dta, replace
	clear

insheet using data/homog/hom_wind/mws6119500.txt		// Wiarton ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	replace v=v[_n-1]+(v[_n+2]-v[_n-1])/3 if v==.		// interpolate missing values
	generate ncity=7
sum
	save data/m7.dta, replace
	clear

insheet using data/homog/hom_wind/mws1077500.txt		// Smithers BC
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=8
sum
	save data/m8.dta, replace
	clear

insheet using data/homog/hom_wind/mws1026270.txt		// *Port Hardy* near Quats BC
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	generate ncity=9
sum
	save data/m9.dta, replace
	clear

insheet using data/homog/hom_wind/mws6034075.txt		// Kenora ON
	drop if _n<3
	keep v1 v2 v4 v6 v8 v10 v12 v14 v16 v18 v20 v22 v24 
	rename v1 year
	destring, replace
	mvdecode v*, mv(-9999.9) 		// convert missing vars to "."
	reshape long v, i(year) j(month)
	replace month=month/2
	drop if year<`start'
	drop if year>2006
	replace v=v[_n-1]+(v[_n+1]-v[_n-1])/2 if v==.		// interpolate missing value
	generate ncity=10
sum
	save data/m10.dta, replace
	clear

use data/m1					// Form long data set
	append using data/m2
	append using data/m3
	append using data/m4
	append using data/m5
	append using data/m6
	append using data/m7
	append using data/m8
	append using data/m9
	append using data/m10

rename v r_wind_mon

sum

	save data/r_wind_mon.dta, replace			// MONTHLY HOMOGENIZED MINTEMP DATA FOR RURAL SITES
	clear



use data/u_wind_mon.dta				 
	merge using data/r_min_mon.dta
	drop _merge
	save data/temp, replace

clear

use data/temp.dta				 
	merge using data/u_min_mon.dta
	drop _merge
	save data/temp.dta, replace

clear

use data/temp.dta				 
	merge using data/r_wind_mon.dta
	drop _merge
	save data/temp.dta, replace




sum


generate umin_anom=0
generate rmin_anom=0
generate uwind_anom=0
generate rwind_anom=0

forvalues i=1/10		{

	bysort month: egen avg=mean(u_min_mon) 	if ncity==`i'
	replace umin_anom=u_min_mon-avg			if ncity==`i'
	drop avg

	bysort month: egen avg=mean(r_min_mon) 	if ncity==`i'
	replace rmin_anom=r_min_mon-avg			if ncity==`i'
	drop avg

	bysort month: egen avg=mean(u_wind_mon) 	if ncity==`i'
	replace uwind_anom=u_wind_mon-avg		if ncity==`i'
	drop avg

	bysort month: egen avg=mean(r_wind_mon) 	if ncity==`i'
	replace rwind_anom=r_wind_mon-avg		if ncity==`i'
	drop avg


				}
	sort city year month

sum

* 	while still using monthly data, generate quarter indicator
	generate mf=month/12			// month fraction
	generate quarter=1+(mf>0.25)+(mf>0.5)+(mf>0.75)
	generate sq=(ncity-1)*184+4*(year-`start')+quarter		// sample quarter

	rename umin_anom tempu									// simplify names
	rename rmin_anom tempr
	rename uwind_anom windu
	rename rwind_anom windr

	save data/monthlywindpop.dta, replace						// MERGED DATA SETS




***************************************************************************************
*
*		COMPONENT E: POPULATION 
*
***************************************************************************************
clear

*	Population data

insheet using data/population.csv, c
	drop if _n<12 | _n>213
	destring, replace
	rename v1 date
	drop v2 

generate yy=real(substr(date,1,4))	// extract year portion of date string, convert to real 
*generate qq=real(substr(date,6,7))	// extract quarter portion of date string, convert to real 

drop if yy>2006

	rename v3 bc
	rename v4 ns
	rename v5 pq
	rename v6 on
	rename v7 ma
	rename v8 sk
	rename v9 ab

	stack yy ab yy ab yy pq yy on yy sk yy sk yy on yy bc yy bc yy ma ///
		, into(pyear pop)
	drop _stack

merge using data/monthlywindpop.dta			// read in temp and wind data
	drop _merge	

generate mpop=pop[sq]/1000000			// expand pop figures from annual to monthly, put in millions

drop pyear mf sq pop

drop if year<`start'

sum

save data/monthlywindpop.dta, replace			// MERGED DATA SETS

exit






















